@@ -22,13 +22,13 @@ Tests for the lepl.regexp.unicode module.
 
 from unittest import TestCase
 
-from logging import basicConfig, DEBUG
+#from logging import basicConfig, DEBUG
 from lepl import RegexpError, DEFAULT_STREAM_FACTORY
-from lepl.regexp.core import NfaGraph, NfaToDfa, Regexp
+from lepl.regexp.core import NfaGraph, NfaToDfa, Expression
 from lepl.regexp.unicode import UnicodeAlphabet
 
 
-# pylint: disable-msg=C0103, C0111, C0301
+# pylint: disable-msg=C0103, C0111, C0301, R0201, R0904
 # (dude this is just a test)
 
 
@@ -36,7 +36,7 @@ UNICODE = UnicodeAlphabet.instance()
 
 
 def _test_parser(regexp):
-    return Regexp.single(UNICODE, regexp, 'label')
+    return Expression.single(UNICODE, regexp, 'label')
 
 class CharactersTest(TestCase):
     
